@@ -1,4 +1,4 @@
-__version__ = "0.2.1"
+__version__ = "0.2.5"
 import os
 import argparse
 from rich.console import Console
@@ -243,11 +243,39 @@ def rich_table(title, cols, rows, attributes):
 def html_table(title, cols, rows, attributes):
     style(put_html(f"<h1>{title}</h1>"), "color:green")
     table = []
+    table.append(cols)
     if len(rows) > 0:
         if type(rows[0]) is tuple:  # check 1st element of list is tuple
             # console.print("Tuple section")
             for i, row in enumerate(rows):
-                table.append([style(put_text(i + 1), "color:green"), *row])
+                if type(row[0]) is str:  # check 1st element of tuple is str
+                    table.append([style(put_text(i + 1), "color:green"), *row])
+                if type(row[0]) is list:  # check 1st element of tuple is list
+                    ll = [*row]
+                    ll.sort(key=len)
+
+                    smalllist = ll[0]
+                    mediumlist = ll[1]
+                    highlist = ll[2]
+                    collectedlist = []
+                    for i in range(len(highlist)):
+                        highVal = highlist[i]
+                        mediumVal = ""
+                        smallVal = ""
+                        if i < len(mediumlist):
+                            mediumVal = mediumlist[i]
+                        if i < len(smalllist):
+                            smallVal = smalllist[i]
+                        table.append(
+                            [
+                                style(put_text(i + 1), "color:green"),
+                                highVal,
+                                mediumVal,
+                                smallVal,
+                            ]
+                        )
+
+                    # table.append([*collectedlist])
         elif type(rows[0]) is str:
             for i, row in enumerate(rows):
                 table.append([style(put_text(i + 1), "color:green"), row])
